==> unit-elements-1.3.29.jar: gen/displays/templates/NodeDownloadDialog.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiTemplateStamp from "alexandria-ui-elements/src/displays/components/TemplateStamp";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiSelectorComboBox from "alexandria-ui-elements/src/displays/components/SelectorComboBox";
import UiSelectorRadioBox from "alexandria-ui-elements/src/displays/components/SelectorRadioBox";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import UiDivider from "alexandria-ui-elements/src/displays/components/Divider";
import UiAction from "alexandria-ui-elements/src/displays/components/Action";
import UiDownload from "alexandria-ui-elements/src/displays/components/Download";
import DisplaysDownloadDialogOption from "unit-elements/gen/displays/templates/DownloadDialogOption";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import NodeDownloadDialogNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import NodeDownloadDialogRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class NodeDownloadDialog extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new NodeDownloadDialogNotifier(this);
		this.requester = new NodeDownloadDialogRequester(this);
	};

	render() {
		const display = !this.state.visible ? {display:'none'} : undefined;
		const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock layout="flexible" width="100.0%" height="100.0%" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844" format="autoOverflow" layout="flexible" width="100.0%" height="calc(100% - 50px)">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087" format="airBottom" layout="vertical">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1339004306" format="airBottom" mode="normal" value="Indique el formato de descarga">
						</UiText>
						<UiSelectorComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153" multipleSelection={false} placeholder="Seleccione un formato" maxMenuHeight={300}>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153.a576608980" name="pdf" mode="normal" value="Formato de documento portátil (pdf)">
							</UiText>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153.a576596968" name="csv" mode="normal" value="Valores separados por coma (csv)">
							</UiText>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153.a576616929" name="xls" mode="normal" value="Documento de Excel (xls)">
							</UiText>
						</UiSelectorComboBox>
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a_782460299" format="body2 middleAirTop red" visible={false} mode="normal">
						</UiText>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588" format="airBottom doubleAirTop" layout="vertical">
						<UiSelectorRadioBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a792390491" label="Indique las columnas de la cabecera del documento" multipleSelection={false} layout="Vertical">
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a792390491.a_2082594208" name="allColumns" mode="normal" value="Todas las columnas">
							</UiText>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a792390491.a_1546627768" name="customColumns" mode="normal" value="Seleccionar las columnas del documento">
							</UiText>
						</UiSelectorRadioBox>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a_969821436" visible={false} layout="vertical">
							<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a_969821436.a1911987299" multiple={{instances:"options",arrangement:"Vertical",noItemsMessage:"",spacing:0,editable:false,wrap:true,collapsed:false,count:{min:0,max:-1}}}>
							</UiMultiple>
						</UiBlock>
					</UiBlock>
				</UiBlock>
				<UiDivider context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_258597308">
				</UiDivider>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1065096756" layout="horizontal endjustified">
					<UiAction context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1065096756.a1691745114" title="Cancelar" target="self" mode="Button" size="Small" format="airRight">
					</UiAction>
					<UiDownload context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1065096756.a1636008424" title="Aceptar" target="self" mode="Button" size="Small">
					</UiDownload>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(NodeDownloadDialog));
DisplayFactory.register("NodeDownloadDialog", withStyles(styles, { withTheme: true })(withSnackbar(NodeDownloadDialog)));

==> unit-elements-2.1.8.jar: gen/displays/templates/NodeDownloadDialog.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiTemplateStamp from "alexandria-ui-elements/src/displays/components/TemplateStamp";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiSelectorComboBox from "alexandria-ui-elements/src/displays/components/SelectorComboBox";
import UiSelectorRadioBox from "alexandria-ui-elements/src/displays/components/SelectorRadioBox";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import UiDivider from "alexandria-ui-elements/src/displays/components/Divider";
import UiAction from "alexandria-ui-elements/src/displays/components/Action";
import UiDownload from "alexandria-ui-elements/src/displays/components/Download";
import DisplaysDownloadDialogOption from "unit-elements/gen/displays/templates/DownloadDialogOption";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import NodeDownloadDialogNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import NodeDownloadDialogRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class NodeDownloadDialog extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new NodeDownloadDialogNotifier(this);
		this.requester = new NodeDownloadDialogRequester(this);
	};

	render() {
		const display = !this.state.visible ? {display:'none'} : undefined;
		const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock layout="flexible" width="100.0%" height={this.fixHeight != null ? this.fixHeight("100.0%") : "100.0%"} style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844" format="autoOverflow" layout="flexible" width="100.0%" height="calc(100% - 50px)">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087" format="airBottom" layout="vertical">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1339004306" format="airBottom" mode="normal" value="Indique el formato de descarga">
						</UiText>
						<UiSelectorComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153" multipleSelection={false} placeholder="Seleccione un formato" maxMenuHeight={300}>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153.a576608980" name="pdf" mode="normal" value="Formato de documento portátil (pdf)">
							</UiText>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153.a576596968" name="csv" mode="normal" value="Valores separados por coma (csv)">
							</UiText>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a1888613153.a576616929" name="xls" mode="normal" value="Documento de Excel (xls)">
							</UiText>
						</UiSelectorComboBox>
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_493683087.a_782460299" format="body2 middleAirTop red" visible={false} mode="normal">
						</UiText>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588" format="airBottom doubleAirTop" layout="vertical">
						<UiSelectorRadioBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a792390491" label="Indique las columnas de la cabecera del documento" multipleSelection={false} layout="Vertical">
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a792390491.a_2082594208" name="allColumns" mode="normal" value="Todas las columnas">
							</UiText>
							<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a792390491.a_1546627768" name="customColumns" mode="normal" value="Seleccionar las columnas del documento">
							</UiText>
						</UiSelectorRadioBox>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a_969821436" visible={false} layout="vertical">
							<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2102873844.a_757175588.a_969821436.a1911987299" multiple={{instances:"options",arrangement:"Vertical",noItemsMessage:"",spacing:0,editable:false,wrap:true,collapsed:false,count:{min:0,max:-1}}}>
							</UiMultiple>
						</UiBlock>
					</UiBlock>
				</UiBlock>
				<UiDivider context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_258597308">
				</UiDivider>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1065096756" layout="horizontal endjustified">
					<UiAction context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1065096756.a1691745114" title="Cancelar" target="self" mode="Button" size="Small" format="airRight">
					</UiAction>
					<UiDownload context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1065096756.a1636008424" title="Aceptar" target="self" mode="Button" size="Small">
					</UiDownload>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(NodeDownloadDialog));
DisplayFactory.register("NodeDownloadDialog", withStyles(styles, { withTheme: true })(withSnackbar(NodeDownloadDialog)));
